aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--test_iso.pl16
1 files changed, 9 insertions, 7 deletions
diff --git a/test_iso.pl b/test_iso.pl
index ba9aab2..bd3e03d 100644
--- a/test_iso.pl
+++ b/test_iso.pl
@@ -45,6 +45,8 @@ my $harness = TAP::Harness->new({
]
});
+my $ts0 = time();
+
print "# Date: ", `date --rfc-3339='ns' -u`;
print "# Testing: $image_path\n";
print "# Host: ", `uname -n`;
@@ -60,19 +62,19 @@ print "... ok\n";
my $name = basename($image_path);
my %info = Tools::parse_mageia_iso_name($name);
-# FIXME the difference is actually regular versus LiveCD
-if ($info{medium} eq "DVD") {
+if ($info{variant} =~ m/^LiveCD/) {
+ # TODO: LiveCD specific tests
+} else {
$harness->runtests(glob_('t_install_iso/*.t'));
-} elsif ($info{medium} eq "CD") {
- # LiveCD specific
- # CD specific
}
# Umounting the ISO
print "# Umounting ISO\n";
# FIXME this fails sometimes; no idea why. Force umount?
system 'umount /media/iso_check';
system 'rm -r /media/iso_check';
print "... ok\n";
print "# Date: ", `date --rfc-3339='ns' -u`;
-print "# Test is over.\n";
+
+my $tdiff = time() - $ts0;
+print "# Tested $name in $tdiff seconds.\n";
@@ -60,19 +62,19 @@ print "... ok\n";
# Umounting the ISO
print "# Umounting ISO\n";
-# FIXME this fails sometimes; no idea why. Force umount?
+# FIXME this fails sometimes (with LiveCDs); no idea why. Force umount?
system 'umount /media/iso_check';
system 'rm -r /media/iso_check';